Cornac: A Comparative Framework for Multimodal Recommender Systems
==================================================================

**Cornac** is a comparative framework for multimodal recommender systems. It focuses on making it **convenient** to work with models leveraging **auxiliary data** (e.g., item descriptive text and image, social network, etc). **Cornac** enables **fast** experiments and **straightforward** implementations of new models. It is **highly compatible** with existing machine learning libraries (e.g., TensorFlow, PyTorch).


.. toctree::
   :glob:
   :maxdepth: 1
   :caption: Getting Started

   Installation <https://github.com/PreferredAI/cornac/blob/master/README.md#installation>
   First experiment <https://github.com/PreferredAI/cornac/blob/master/README.md#getting-started-your-first-cornac-experiment>
   Examples <https://github.com/PreferredAI/cornac/tree/master/examples#cornac-examples-directory>
   Tutorials <https://github.com/PreferredAI/cornac/tree/master/tutorials#tutorials>


.. toctree::
   :maxdepth: 1
   :caption: API Reference

   data
   models
   metrics
   eval_methods
   experiment
   datasets
   hyperopt
   
